#!/bin/sh

if $leg_is_restart
then
    nemo_restart=".TRUE."
else
    if [[ $rstctl -eq 1 ]]; then
       nemo_restart=".FALSE."
    else
       nemo_restart=".TRUE."
    fi
fi

case $advsch in
  cen2) LCEN2=.true.
        LTVD=.false.;;
  tvd)  LCEN2=.false.
        LTVD=.true.;;
  *    ) print "Unknown testcase"
         exit 1;;
esac

cat << EOF
!-----------------------------------------------------------------------
&namrun        !  Parameters of the run
!-----------------------------------------------------------------------
   nn_no       =       0          ! Job number
   cn_exp      = "${exp_name}"
   nn_it000    =  $(( leg_start_sec / nem_time_step_sec + 1 ))
   nn_itend    =  $(( leg_end_sec / nem_time_step_sec ))
   nn_date0    =  ${leg_start_date_yyyymmdd}
   nn_leapy    =       1          ! Leap year calendar (1) or not (0)
   ln_rstart   = ${nemo_restart}  ! Start from rest (F) or from a restart file (T)
   nn_rstctl   = ${rstctl}        ! Restart control = 0 nn_it000 is not compared to the restart file value
                                  !                 = 1 use nn_date0 in namelist (not the value in the restart file)
                                  !                 = 2 calendar parameters read in the restart file
   cn_ocerst_in  = "restart_oce"  ! Suffix of ocean restart name (input)
   cn_ocerst_out = "restart_oce"  ! Suffix of ocean restart name (output)
   nn_istate   =       0          ! Output the initial state (1) or not (0)
   nn_stock    =       0          ! Frequency of creation of a restart file (modulo referenced to 1)
   nn_write    =      -1          ! Frequency of write in the output file   (modulo referenced to nn_it000)
   ln_dimgnnn  = .false.          ! DIMG file format: 1 file for all processors (F) or by processor (T)
/
!-----------------------------------------------------------------------
&namzgr        !  Vertical coordinate
!-----------------------------------------------------------------------
   ln_zco      = .false.     ! z-coordinate - full    steps   (T/F)      ("key_zco" may also be defined)
   ln_zps      = .true.      ! z-coordinate - partial steps   (T/F)
   ln_sco      = .false.     ! s- or hybrid z-s-coordinate    (T/F)
/
!-----------------------------------------------------------------------
&namdom        !  Space and time domain (bathymetry, mesh, timestep)
!-----------------------------------------------------------------------
   nn_bathy    =    1        ! Compute (=0) or read (=1) the bathymetry file
   nn_closea   =    0        ! Remove (=0) or keep (=1) closed seas and lakes (ORCA)
   nn_msh      =    0        ! Create (=1) a mesh file or not (=0)
                             !
   rn_e3zps_min=   25.       ! Partial step thickness is set larger than the minimum of
   rn_e3zps_rat=    0.2      ! rn_e3zps_min and rn_e3zps_rat*e3t, with 0<rn_e3zps_rat<1
                             !
   rn_rdt      = ${nem_time_step_sec}  !  Time step for the dynamics (and tracer if nn_acc=0)
   nn_baro     =   60        ! Number of barotropic time step            ("key_dynspg_ts")
   rn_atfp     =    0.1      ! Asselin time filter parameter
   nn_acc      =    0        ! Acceleration of convergence : =1      used, rdt < rdttra(k)
                             !                               =0, not used, rdt = rdttra
/
!-----------------------------------------------------------------------
&namsbc        !  Surface Boundary Condition (surface module)
!-----------------------------------------------------------------------
   nn_fsbc     = $(( lim_time_step_sec / nem_time_step_sec ))
                             ! Frequency of surface boundary condition computation
                             !     (also = the frequency of sea-ice model call)
   ln_ana      = .false.     ! Analytical formulation                    (T => fill namsbc_ana )
   ln_flx      = .false.     ! Flux formulation                          (T => fill namsbc_flx )
   ln_blk_clio = .false.     ! CLIO bulk formulation                     (T => fill namsbc_clio)
   ln_blk_core = .false.     ! CORE bulk formulation                     (T => fill namsbc_core)
   ln_cpl      = .true.      ! Coupled formulation                       (T => fill namsbc_cpl )
   ln_apr_dyn  = .false.     ! Patm gradient added in ocean & ice Eqs.   (T => fill namsbc_apr )
   nn_ice      = 2           !     =0 no ice boundary condition   ,
                             !     =1 use observed ice-cover      ,
                             !     =2 ice-model used                     ("key_lim3" or "key_lim2")
   ln_dm2dc    = .false.     ! Daily mean to diurnal cycle on short wave
   ln_rnf      = .false.     ! Runoffs                                   (T => fill namsbc_rnf)
   ln_ssr      = .false.     ! Sea Surface Restoring on T and/or S       (T => fill namsbc_ssr)
   nn_fwb      = 0           ! FreshWater Budget: =0 unchecked
                             !     =1 global mean of e-p-r set to zero at each time step
                             !     =2 annual global mean of e-p-r set to zero
                             !     =3 global emp set to zero and spread out over erp area
/
!-----------------------------------------------------------------------
&namsbc_cpl    !  Coupled ocean/atmosphere model        ("key_coupled")
!-----------------------------------------------------------------------
!                            ! SEND
cn_snd_temperature= 'oce and ice'        ! 'oce only' 'weighted oce and ice' 'mixed oce-ice'
cn_snd_albedo     = 'ice'                ! 'none' 'weighted ice' 'mixed oce-ice'
cn_snd_thickness  = 'ice and snow'       ! 'none' 'weighted ice and snow'
cn_snd_crt_nature = 'none'               ! 'none' 'oce only' 'weighted oce and ice' 'mixed oce-ice'
cn_snd_crt_refere = 'spherical'          ! 'spherical' 'cartesian'
cn_snd_crt_orient = 'eastward-northward' ! 'eastward-northward' or 'local grid'
cn_snd_crt_grid   = 'T'                  ! 'T'
!                            ! RECEIVE
cn_rcv_w10m       = 'none'               ! 'none' 'coupled'
cn_rcv_taumod     = 'none'               ! 'none' 'coupled'
cn_rcv_tau_nature = 'oce and ice'        ! 'oce only' 'oce and ice' 'mixed oce-ice'
cn_rcv_tau_refere = 'spherical'          ! 'spherical' 'cartesian'
cn_rcv_tau_orient = 'eastward-northward' ! 'eastward-northward' or 'local grid'
cn_rcv_tau_grid   = 'T'                  ! 'T' 'U,V' 'U,V,F' 'U,V,I' 'T,F' 'T,I' 'T,U,V'
cn_rcv_dqnsdt     = 'coupled'            ! 'none' 'coupled'
cn_rcv_qsr        = 'oce and ice'        ! 'conservative' 'oce and ice' 'mixed oce-ice'
cn_rcv_qns        = 'oce and ice'        ! 'conservative' 'oce and ice' 'mixed oce-ice'
cn_rcv_emp        = 'conservative'       ! 'conservative' 'oce and ice' 'mixed oce-ice'
cn_rcv_rnf        = 'coupled'            ! 'coupled' 'climato' 'mixed'
cn_rcv_cal        = 'coupled'            ! 'none' 'coupled'
/
!-----------------------------------------------------------------------
&namtra_qsr    !  Penetrative solar radiation
!-----------------------------------------------------------------------
!              !  file name  ! frequency (hours) ! variable  ! time interp. !  clim  ! 'yearly'/ ! weights  ! rotation !
!              !             !  (if <0  months)  !   name    !   (logical)  !  (T/F) ! 'monthly' ! filename ! pairing  !
   sn_chl      ='chlorophyll',        -1         , 'CHLA'    ,   .true.     , .true. , 'yearly'  , ''       , ''
                             !
   cn_dir      = './'        ! Root directory for the location of the runoff files
   ln_traqsr   = .true.      ! Light penetration (T) or not (F)
   ln_qsr_rgb  = .false.     ! RGB (Red-Green-Blue) light penetration
   ln_qsr_2bd  = .true.      ! 2 bands              light penetration
   ln_qsr_bio  = .false.     ! Bio-model light penetration
   nn_chldta   =      0      ! RGB : Chl data (=1) or cst value (=0)
   rn_abs      =   0.58      ! RGB & 2 bands: fraction of light (rn_si1)
   rn_si0      =   0.35      ! RGB & 2 bands: shortess depth of extinction
   rn_si1      =   23.0      ! 2 bands: longest depth of extinction
/
!-----------------------------------------------------------------------
&namsbc_rnf    !  Runoffs namelist surface boundary condition
!-----------------------------------------------------------------------
!              !  file name           ! frequency (hours) ! variable  ! time interp. !  clim  ! 'yearly'/ ! weights  ! rotation !
!              !                      !  (if <0  months)  !   name    !   (logical)  !  (T/F) ! 'monthly' ! filename ! pairing  !
   sn_rnf      = 'runoff_1m_nomask'   ,        -1         , 'sorunoff',   .true.     , .true. , 'yearly'  , ''       , ''
   sn_cnf      = 'runoff_1m_nomask'   ,         0         , 'socoefr0',   .false.    , .true. , 'yearly'  , ''       , ''
   sn_s_rnf    = 'runoffs'            ,        24         , 'rosaline',   .true.     , .true. , 'yearly'  , ''       , ''
   sn_t_rnf    = 'runoffs'            ,        24         , 'rotemper',   .true.     , .true. , 'yearly'  , ''       , ''
   sn_dep_rnf  = 'runoffs'            ,         0         , 'rodepth' ,   .false.    , .true. , 'yearly'  , ''       , ''
                             !
   cn_dir       = './'       ! Root directory for the location of the runoff files
   ln_rnf_emp   = .false.    ! Runoffs included into precipitation field (T) or into a file (F)
   ln_rnf_mouth = .false.    ! Specific treatment at rivers mouths
   rn_hrnf      =   0.e0     ! Depth over which enhanced vertical mixing is used
   rn_avt_rnf   =   1.e-3    ! Value of the additional vertical mixing coef. [m2/s]
/
!-----------------------------------------------------------------------
&namsbc_alb    !  Albedo parameters
!-----------------------------------------------------------------------
   rn_cloud    =    0.06     ! Cloud correction to snow and ice albedo
   rn_albice   =    0.53     ! Albedo of melting ice in the arctic and antarctic
   rn_alphd    =    0.80     ! Coefficients for linear interpolation used to
   rn_alphc    =    0.65     ! Compute albedo between two extremes values
   rn_alphdi   =    0.72     ! (Pyane, 1972)
/
!-----------------------------------------------------------------------
&namlbc        !  Lateral momentum boundary condition
!-----------------------------------------------------------------------
   rn_shlat    =    0.5      !     shlat = 0 : free slip
                             ! 0 < shlat < 2 : partial slip
                             !     shlat = 2 : no slip
                             ! 2 < shlat     : strong slip
/
!-----------------------------------------------------------------------
&namcla        !  Cross land advection
!-----------------------------------------------------------------------
   nn_cla      =    0        ! Advection between 2 ocean pts separates by land
/
!-----------------------------------------------------------------------
&nambfr        !  Bottom friction
!-----------------------------------------------------------------------
   nn_bfr      =    2        ! Type of bottom friction :   = 0 : free slip,  = 1 : linear friction
                             !                             = 2 : nonlinear friction
   rn_bfri1    =    4.e-4    ! Bottom drag coefficient (linear case)
   rn_bfri2    =    1.e-3    ! Bottom drag coefficient (non linear case)
   rn_bfeb2    =    2.5e-3   ! Bottom turbulent kinetic energy background  (m2/s2)
/
!-----------------------------------------------------------------------
&nambbc        !  Bottom temperature boundary condition
!-----------------------------------------------------------------------
! Use defaults
/
!-----------------------------------------------------------------------
&nambbl        !  Bottom boundary layer scheme
!-----------------------------------------------------------------------
   nn_bbl_ldf  =  1          ! Diffusive bbl (=1)   or not (=0)
   nn_bbl_adv  =  0          ! Advective bbl (=1/2) or not (=0)
   rn_ahtbbl   =  1000.      ! Lateral mixing coefficient in the bbl  [m2/s]
   rn_gambbl   =  10.        ! Advective bbl coefficient                 [s]
/
!-----------------------------------------------------------------------
&nameos        !  Ocean physical parameters
!-----------------------------------------------------------------------
   nn_eos      =   0         ! Type of equation of state and Brunt-Vaisala frequency
                             !    = 0, UNESCO (formulation of Jackett and McDougall (1994) and of McDougall (1987) )
                             !    = 1, linear: rho(T)   = rau0 * ( 1.028 - ralpha * T )
                             !    = 2, linear: rho(T,S) = rau0 * ( rbeta * S - ralpha * T )
   rn_alpha    =   2.0e-4    ! Thermal expension coefficient (nn_eos= 1 or 2)
   rn_beta     =   7.7e-4    ! Saline  expension coefficient (nn_eos= 2)
/
!-----------------------------------------------------------------------
&namtra_adv    !  Advection scheme for tracer
!-----------------------------------------------------------------------
   ln_traadv_cen2   =  $LCEN2  ! 2nd order centered scheme
   ln_traadv_tvd    =  $LTVD   ! TVD scheme
   ln_traadv_muscl  =  .false.  ! MUSCL scheme
   ln_traadv_muscl2 =  .false.  ! MUSCL2 scheme + cen2 at boundaries
   ln_traadv_ubs    =  .false.  ! UBS scheme
   ln_traadv_qck    =  .false.  ! QUCIKEST scheme
/
!-----------------------------------------------------------------------
&namtra_ldf    !  Lateral diffusion scheme for tracer
!-----------------------------------------------------------------------
   !                         ! Type of the operator :
   ln_traldf_lap    =  .true.   ! Laplacian operator
   ln_traldf_bilap  =  .false.  ! Bilaplacian operator
   !                         ! Direction of action  :
   ln_traldf_level  =  .false.  ! Iso-level
   ln_traldf_hor    =  .false.  ! Horizontal (geopotential) (require "key_ldfslp" when ln_sco=T)
   ln_traldf_iso    =  .true.   ! Iso-neutral               (require "key_ldfslp")
!                               ! Coefficient
   rn_aht_0         =   300.    ! Horizontal eddy diffusivity for tracers [m2/s]
   rn_ahtb_0        =     0.    ! Background eddy diffusivity for ldf_iso [m2/s]
   rn_aeiv_0        =     0.    ! Eddy induced velocity coefficient [m2/s] (require "key_traldf_eiv")
/
!-----------------------------------------------------------------------
&namdyn_adv    !  Formulation of the momentum advection
!-----------------------------------------------------------------------
   ln_dynadv_vec = .true.    ! Vector form (T) or flux form (F)
   ln_dynadv_cen2= .false.   ! Flux form - 2nd order centered scheme
   ln_dynadv_ubs = .false.   ! Flux form - 3rd order UBS      scheme
/
!-----------------------------------------------------------------------
&namdyn_vor    !  Option of physics/algorithm (not control by CPP keys)
!-----------------------------------------------------------------------
   ln_dynvor_ene = .false.   ! Enstrophy conserving scheme
   ln_dynvor_ens = .false.   ! Energy conserving scheme
   ln_dynvor_mix = .false.   ! Mixed scheme
   ln_dynvor_een = .true.    ! Energy & enstrophy scheme
/
!-----------------------------------------------------------------------
&namdyn_hpg    !  Hydrostatic pressure gradient option
!-----------------------------------------------------------------------
   ln_hpg_zco  = .false.     ! z-coordinate - full steps
   ln_hpg_zps  = .true.      ! z-coordinate - partial steps (interpolation)
   ln_hpg_sco  = .false.     ! s-coordinate (standard jacobian formulation)
   ln_hpg_hel  = .false.     ! s-coordinate (helsinki modification)
   ln_hpg_wdj  = .false.     ! s-coordinate (weighted density jacobian)
   ln_hpg_djc  = .false.     ! s-coordinate (Density Jacobian with Cubic polynomial)
   ln_hpg_rot  = .false.     ! s-coordinate (ROTated axes scheme)
   rn_gamma    = 0.e0        ! Weighting coefficient (wdj scheme)
   ln_dynhpg_imp = .true.    ! Hydrostatic pressure gradient: semi-implicit time scheme  (T)
                             !                                centered      time scheme  (F)
/
!-----------------------------------------------------------------------
&namdyn_ldf    !  Lateral diffusion on momentum
!-----------------------------------------------------------------------
   !                         ! Type of the operator :
   ln_dynldf_lap    =  .false.  ! Laplacian operator
   ln_dynldf_bilap  =  .true.   ! Bilaplacian operator
   !                         ! Direction of action  :
   ln_dynldf_level  =  .false.  ! Iso-level
   ln_dynldf_hor    =  .true.   ! Horizontal (geopotential)  (require "key_ldfslp" in s-coord.)
   ln_dynldf_iso    =  .false.  ! Iso-neutral                (require "key_ldfslp")
   !                         ! Coefficient
   rn_ahm_0_lap     =     0.    ! Horizontal laplacian eddy viscosity   [m2/s]
   rn_ahm_0_blp     =   -1.5e11 ! Horizontal bilaplacian eddy viscosity [m4/s]
   rn_ahmb_0        =     0.    ! Background eddy viscosity for ldf_iso [m2/s]
/
!-----------------------------------------------------------------------
&namzdf        !  Vertical physics
!-----------------------------------------------------------------------
   rn_avm0     =   1.e-4     ! Vertical eddy viscosity   [m2/s]  (background Kz if not "key_zdfcst")
   rn_avt0     =   1.e-5     ! Vertical eddy diffusivity [m2/s]  (background Kz if not "key_zdfcst")
   nn_avb      =    0        ! Profile for background avt & avm (=1) or not (=0)
   nn_havtb    =    0        ! Horizontal shape for avtb (=1) or not (=0)
   ln_zdfevd   = .true.      ! Enhanced vertical diffusion (evd) (T) or not (F)
   nn_evdm     =    0        ! Evd apply on tracer (=0) or on tracer and momentum (=1)
   rn_avevd    =   10.       ! Evd mixing coefficient [m2/s]
   ln_zdfnpc   = .false.     ! Non-Penetrative Convective algorithm (T) or not (F)
   nn_npc      =    1        !    Frequency of application of npc
   nn_npcp     =  365        !    npc control print frequency
   ln_zdfexp   = .false.     ! Time-stepping: split-explicit (T) or implicit (F) time stepping
   nn_zdfexp   =    3        !    Number of sub-timestep for ln_zdfexp=T
/
!-----------------------------------------------------------------------
&namzdf_ric    !  Richardson number dependent vertical diffusion       ("key_zdfric")
!-----------------------------------------------------------------------
   rn_avmri    = 100.e-4     ! Maximum value of the vertical viscosity
   rn_alp      =   5.        ! Coefficient of the parameterization
   nn_ric      =   2         ! Coefficient of the parameterization
/
!-----------------------------------------------------------------------
&namzdf_tke    !  Turbulent eddy kinetic dependent vertical diffusion  ("key_zdftke")
!-----------------------------------------------------------------------
   rn_ediff    =   0.1       ! Coef. for vertical eddy coef. (avt=rn_ediff*mxl*sqrt(e) )
   rn_ediss    =   0.7       ! Coef. of the Kolmogoroff dissipation
   rn_ebb      =  60.        ! Coef. of the surface input of tke (=67.83 suggested when ln_mxl0=T)
   rn_emin     =   1.e-6     ! Minimum value of tke [m2/s2]
   rn_emin0    =   1.e-4     ! Surface minimum value of tke [m2/s2]
   nn_mxl      =   3         ! Mixing length: = 0 bounded by the distance to surface and bottom
                             !                = 1 bounded by the local vertical scale factor
                             !                = 2 first vertical derivative of mixing length bounded by 1
                             !                = 3 as =2 with distinct disspipative an mixing length scale
   nn_pdl      =   1         ! Prandtl number function of richarson number (=1, avt=pdl(Ri)*avm) or not (=0, avt=avm)
   ln_mxl0     = .true.      ! Surface mixing length scale = F(wind stress) (T) or not (F)
   rn_mxl0     =   0.04      ! Surface  buoyancy lenght scale minimum value
   ln_lc       = .false.     ! Langmuir cell parameterisation (Axell 2002)
   rn_lc       =   0.15      ! Coef. associated to Langmuir cells
   nn_etau     =   1         ! Penetration of tke below the mixed layer (ML) due to internal & intertial waves
                             !       = 0 no penetration
                             !       = 1 add a tke source below the ML
                             !       = 2 add a tke source just at the base of the ML
                             !       = 3 as = 1 applied on HF part of the stress    ("key_coupled")
   rn_efr      =   0.05      ! Fraction of surface tke value which penetrates below the ML (nn_etau=1 or 2)
   nn_htau     =   1         ! Type of exponential decrease of tke penetration below the ML
                             !       = 0  constant 10 m length scale
                             !       = 1  0.5m at the equator to 30m poleward of 40 degrees
/
!------------------------------------------------------------------------
&namzdf_kpp    !  K-Profile Parameterization dependent vertical mixing  ("key_zdfkpp", and optionally:
!------------------------------------------------------------------------
   ln_kpprimix = .true.      ! Shear instability mixing
   rn_difmiw   =  1.0e-04    ! Constant internal wave viscosity [m2/s]
   rn_difsiw   =  0.1e-04    ! Constant internal wave diffusivity [m2/s]
   rn_riinfty  =  0.8        ! Local Richardson Number limit for shear instability
   rn_difri    =  0.0050     ! Maximum shear mixing at Rig = 0    [m2/s]
   rn_bvsqcon  = -0.01e-07   ! Brunt-Vaisala squared for maximum convection [1/s2]
   rn_difcon   =  1.         ! Maximum mixing in interior convection [m2/s]
   nn_avb      =  0          ! Horizontal averaged (=1) or not (=0) on avt and amv
   nn_ave      =  1          ! Constant (=0) or profile (=1) background on avt
/
!-----------------------------------------------------------------------
&namzdf_ddm    !  Double diffusive mixing parameterization             ("key_zdfddm")
!-----------------------------------------------------------------------
   rn_avts     = 1.e-4       ! Maximum avs (vertical mixing on salinity)
   rn_hsbfr    = 1.6         ! Heat/salt buoyancy flux ratio
/
!-----------------------------------------------------------------------
&namsol        !  Elliptic solver / island / free surface
!-----------------------------------------------------------------------
   nn_solv     =      2      ! Elliptic solver: =1 Preconditioned conjugate gradient (PCG)
                             !                  =2 Successive-over-relaxation (SOR)
                             !                  =3 FETI (fet)             ("key_feti")
                             !                  =4 SOR with extra outer halo
   nn_sol_arp  =      0      ! Absolute/relative (0/1) precision convergence test
   nn_nmin     =    340      ! Minimum of iterations for the SOR solver
   nn_nmax     =  15000      ! Maximum of iterations for the SOR solver
   nn_nmod     =      5      ! Frequency of test for the SOR solver
   rn_eps      = 1.e-15      ! Absolute precision of the solver
   rn_resmax   = 1.e-10      ! Absolute precision for the SOR solver
   rn_sor      = 1.975       ! Optimal coefficient for SOR solver (to be adjusted with the domain)
/
!-----------------------------------------------------------------------
&nammpp        !  Massively Parallel Processing                        ("key_mpp_mpi")
!-----------------------------------------------------------------------
   cn_mpi_send =  'B'        ! MPI send/recieve type   ='S', 'B', or 'I' for standard send,
                             ! Buffer blocking send or immediate non-blocking sends, resp.
   nn_buffer   = 16000000    ! Size in bytes of exported buffer ('B' case), 0 no exportation
   jpni        =   0         ! jpni   Number of processors following i (set automatically if < 1)
   jpnj        =   0         ! jpnj   Number of processors following j (set automatically if < 1)
   jpnij       =   0         ! jpnij  Number of local domains (set automatically if < 1)
/
!-----------------------------------------------------------------------
&namctl        !  Control prints & Benchmark
!-----------------------------------------------------------------------
   ln_ctl      = .false.     ! Trends control print (expensive!)
   nn_print    =    0        ! Level of print (0 no extra print)
   nn_ictls    =    0        ! Start i indice of control sum (use to compare mono versus
   nn_ictle    =    0        ! End   i indice of control sum        multi processor runs
   nn_jctls    =    0        ! Start j indice of control               over a subdomain)
   nn_jctle    =    0        ! End   j indice of control
   nn_isplt    =    1        ! Number of processors in i-direction
   nn_jsplt    =    1        ! Number of processors in j-direction
   nn_bench    =    0        ! Bench mode (1/0): CAUTION use zero except for bench
                             !    (no physical validity of the results)
/
!-----------------------------------------------------------------------
&namtrd        !  Diagnostics on dynamics and/or tracer trends       ("key_trddyn" and/or "key_trdtra")
!              !      or mixed-layer trends or barotropic vorticity  ("key_trdmld" or     "key_trdvor")
!-----------------------------------------------------------------------
   nn_trd            = 365   ! Time step frequency dynamics and tracers trends
   nn_ctls           =   0   ! Control surface type in mixed-layer trends (0,1 or n<jpk)
   rn_ucf            =   1.  ! Unit conversion factor (=1 -> /seconds ; =86400. -> /day)
   cn_trdrst_in      = "restart_mld" ! Suffix of ocean restart name (input)
   cn_trdrst_out     = "restart_mld" ! Suffix of ocean restart name (output)
   ln_trdmld_restart = .false.       ! Restart for ML diagnostics
   ln_trdmld_instant = .false.       ! Flag to diagnose trends of instantantaneous or mean ML T/S
/
!-----------------------------------------------------------------------
&namflo        !  Float parameters                         ("key_float")
!-----------------------------------------------------------------------
   ln_rstflo  = .false.      ! Float restart (T) or not (F)
   nn_writefl =      75      ! Frequency of writing in float output file
   nn_stockfl =    5475      ! Frequency of creation of the float restart file
   ln_argo    = .false.      ! Argo type floats (stay at the surface each 10 days)
   ln_flork4  = .false.      ! Trajectories computed with a 4th order Runge-Kutta (T)
                             !    or computed with Blanke' scheme (F)
/
!-----------------------------------------------------------------------
&namptr       !  Poleward Transport Diagnostic
!-----------------------------------------------------------------------
! Use defaults
/
!-----------------------------------------------------------------------
&namhsb       !  Heat and salt budgets
!-----------------------------------------------------------------------
! Use defaults
/
EOF
